import {AfterViewInit, Component, ElementRef, Input, OnInit, ViewChild} from '@angular/core';

@Component({
  selector: '[uhr]',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent implements AfterViewInit, OnInit {
  @Input() size: string = '100%';

  @Input() autoresize = true;
  @ViewChild('container') container: ElementRef;

  constructor(private element: ElementRef) {
  }

  ngOnInit(): void {
    window.onresize = this.handleResize.bind(this);
  }

  ngAfterViewInit(): void {
    const realWidthInPx = this.determineSizeInPx(this.size);
    this.resizeToPx(realWidthInPx);
  }

  handleResize(event: UIEvent): boolean {
    const parentWidth = AppComponent.getWidth(this.element);
    const parentHeight = AppComponent.getHeight(this.element);
    const windowWidth = window.innerWidth;
    const windowHeight = window.innerHeight;
    this.resizeToPx(Math.min(parentWidth, parentHeight, windowWidth, windowHeight));
    return true;
  }

  private determineSizeInPx(size: string): number {
    if (this.size === 'fill') {
      this.element.nativeElement.style.width = '100%';
      this.element.nativeElement.style.height = '100%';
      const width: number = AppComponent.getWidth(this.container);
      const height: number = AppComponent.getHeight(this.container);
      return Math.min(width, height);
    } else {
      this.container.nativeElement.style.width = size;
      return AppComponent.getWidth(this.container);
    }
  }

  private resizeToPx(size: number): void {
    this.container.nativeElement.style.width = `${size}px`;
    this.container.nativeElement.style.height = `${size}px`;
    this.container.nativeElement.style['font-size'] = `${size / 40}px`;
  }

  private static getWidth(e: ElementRef): number {
    console.log('getting width', e);
    return e.nativeElement.clientWidth;
  }

  private static getHeight(e: ElementRef): number {
    console.log('getting height', e);
    return e.nativeElement.clientHeight;
  }
}

// var setWidth = function () {
// };
// var $ = function (p) {
//   return {
//     append: (a) => ({}),
//     on: (a, b) => ({}),
//     hide: (a?) => ({})
//   };
// };
// var uhrGlobals = {languages: [], themes: []};
// var toggleConfigScreen = function () {
// };
// var setupHTML = function setupHTML() {
//   var e = this.element;
//   // Base clock area
//   e.addClass('uhr');
//   e.empty();
//   e.append('<span class="item dot dot1"></span>');
//   e.append('<span class="item dot dot2"></span>');
//   e.append('<span class="item dot dot3"></span>');
//   e.append('<span class="item dot dot4"></span>');
//   e.append('<div class="letterarea"></div>');
//   e.append('<div class="reflection"></div>');
//   setWidth.bind(this)(this.options.width);
//
//   if (this.options.controls) {
//     var controlpanel = $('<div class="uhr-controlpanel" id="uhr-controlpanel' + this.id + '"></div>');
//     var content = $('<div class="content"></div>');
//     controlpanel.append(content);
//     // on/off switch
//     var toggleSwitch = $('<div class="onoffswitch" id="uhr-onoffswitch' + this.id + '"></div>');
//     toggleSwitch.append('<input type="checkbox" class="onoffswitch-checkbox" id="uhr-onoffswitch-checkbox' + this.id +
//       '" checked="checked" />');
//     toggleSwitch.append('<label class="onoffswitch-label" for="uhr-onoffswitch-checkbox' + this.id + '">' +
//       '<div class="onoffswitch-inner"></div>' + '<div class="onoffswitch-switch"></div>' + '</label>');
//     content.append(toggleSwitch);
//
//     // time mode switch
//     var modeSwitch = $('<div class="onoffswitch" id="uhr-modeswitch' + this.id + '"></div>');
//     modeSwitch.append('<input type="checkbox" class="onoffswitch-checkbox" id="uhr-modeswitch-checkbox' + this.id +
//       '" checked="checked" />');
//     modeSwitch.append('<label class="onoffswitch-label" for="uhr-modeswitch-checkbox' + this.id + '">' +
//       '<div class="modeswitch-inner"></div>' + '<div class="onoffswitch-switch"></div>' +
//       '</label>');
//     content.append(modeSwitch);
//     // language chooser
//     if (uhrGlobals.languages.length > 1) {
//       var languageChooser = $('<select id="uhr-languagechooser' + this.id + '"></select>');
//       uhrGlobals.languages.forEach(function (item) {
//         languageChooser.append('<option value="' + item.code + '">' + item.language + '</option>');
//       });
//       content.append(languageChooser);
//     }
//
//     // theme chooser
//     if (uhrGlobals.themes.length > 1) {
//       var themeChooser = $('<select id="uhr-themechooser' + this.id + '"></select>');
//       uhrGlobals.themes.forEach(function (item) {
//         themeChooser.append('<option value="' + item.styleClass + '">' + item.name + '</option>');
//       });
//       content.append(themeChooser);
//     }
//     var closebutton = $('<a class="uhr-closecontrolpanel" id="uhr-closecontrolpanel' + this.id + '"></a>');
//     closebutton.on('click', function () {
//       $('#uhr-controlpanel' + this.id).hide('fast');
//     }.bind(this));
//     content.append(closebutton);
//     e.after(controlpanel);
//     controlpanel.hide();
//     var configlink = $('<a class="uhr-configlink" id="uhr-configlink' + this.id + '"></a>');
//     configlink.on('click', function () {
//       toggleConfigScreen.bind(this)();
//     }.bind(this));
//     e.after(configlink);
//   }
// };
