/*
 * Copyright (C) Schweizerische Bundesbahnen SBB, 2017.
 */

let es_ist = {1: [1, 2, 4, 5, 6]};
let uhr = {10: [9, 10, 11]};
let nach = {4: [8, 9, 10, 11]};
let vor = {4: [1, 2, 3]};
let halb = {5: [1, 2, 3, 4]};
let fuenf = {1: [8, 9, 10, 11]};
let zehn = {2: [1, 2, 3, 4]};
let viertel = {3: [5, 6, 7, 8, 9, 10, 11]};
let zwanzig = {2: [5, 6, 7, 8, 9, 10, 11]};
let dreiviertel = {3: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11]};

export class LangDe implements Lang {
  readonly code = 'de';
  readonly version = 2;
  readonly name = 'Deutsch';
  readonly letterboard = new Letterboard([
    'ESKISTAFÜNF',
    'ZEHNZWANZIG',
    'DREIVIERTEL',
    'VORFUNKNACH',
    'HALBAELFÜNF',
    'EINSXAMZWEI',
    'DREIPMJVIER',
    'SECHSNLACHT',
    'SIEBENZWÖLF',
    'ZEHNEUNKUHR'
  ]);
  readonly permanent = es_ist;
  readonly minutes = {
    '0,1,2,3,4': uhr,
    '5,6,7,8,9': [fuenf, nach],
    '10,11,12,13,14': [zehn, nach],
    '15,16,17,18,19': [viertel, nach],
    '20,21,22,23,24': [zwanzig, nach],
    '25,26,27,28,29': [fuenf, vor, halb],
    '30,31,32,33,34': halb,
    '35,36,37,38,39': [fuenf, nach, halb],
    '40,41,42,43,44': [zwanzig, vor],
    '45,46,47,48,49': dreiviertel,
    '50,51,52,53,54': [zehn, vor],
    '55,56,57,58,59': [fuenf, vor]
  };
  readonly hours = {
    '0,12': {9: [7, 8, 9, 10, 11]},
    '1,13': {6: [1, 2, 3, 4]},
    '2,14': {6: [8, 9, 10, 11]},
    '3,15': {7: [1, 2, 3, 4]},
    '4,16': {7: [8, 9, 10, 11]},
    '5,17': {5: [8, 9, 10, 11]},
    '6,18': {8: [1, 2, 3, 4, 5]},
    '7,19': {9: [1, 2, 3, 4, 5, 6]},
    '8,20': {8: [8, 9, 10, 11]},
    '9,21': {10: [4, 5, 6, 7]},
    '10,22': {10: [1, 2, 3, 4]},
    '11,23': {5: [6, 7, 8]}
  };
}

interface Lang {
  readonly code: string;
  readonly version: number;
  readonly name: string;
  readonly letterboard: Letterboard;
  readonly permanent?: Definition;
  readonly minutes: Definition;
  readonly hours: Definition;

}

declare type Definition = any;

class Letterboard {
  public readonly letters: string[];

  constructor(letters: string[]) {
    if (letters.length !== 10) {
      throw new Error(`invalid number of lines: ${letters.length}`);
    }
    letters.forEach((line, index) => {
      if (line.length !== 10) {
        throw new Error(`invalid number of letters in line ${index + 1}: ${line.length}`);
      }
    });
    this.letters = letters;
  }
}
